@@ -40,6 +40,8 @@ private Q_SLOTS:
     void testUpdateFoldingMarkersHighlighting();
     void testDdisplayRangeChangedEmitted();
     void testCrashOnPasteInOverwriteMode();
+    void testCommandBarSearchReplace();
+    void testSelectedTextFormats();
 };
 
 #endif // KATE_VIEW_TEST_H
